summaryrefslogtreecommitdiffstats
path: root/desktop-widgets/downloadfromdivecomputer.cpp
diff options
context:
space:
mode:
authorGravatar Berthold Stoeger <bstoeger@mail.tuwien.ac.at>2018-12-23 22:08:00 +0100
committerGravatar Dirk Hohndel <dirk@hohndel.org>2019-01-09 20:58:04 -0800
commit0249e125898134d3f6d4a2a8972f3eeb30c02803 (patch)
tree4830c88c2d61a096a2f1afdcc71bddf8d330cf73 /desktop-widgets/downloadfromdivecomputer.cpp
parentfd196f143ae9c6b3a51b057ba134c5e3a280e30f (diff)
downloadsubsurface-0249e125898134d3f6d4a2a8972f3eeb30c02803.tar.gz
Import: split process_imported_dives() function
Split the process_imported_dives() function in two: 1) process_imported_dives() processes the dives and generates a list of dives and trips to be added and removed. 2) add_imported_dives() calls process_imported_dives() and does the actual removal / addition of dives and trips. The goal is to split preparation and actual work, to make dive import undo-able. The code adds extra checks to never merge into the same dive twice, as this would lead to a double-free() bug. This should in principle never happen, as dives that compare equal according to is_same_dive() are merged in the imported-dives list, but perhaps in some pathologival corner-cases is_same_dive() turns out to be non-transitive. Signed-off-by: Berthold Stoeger <bstoeger@mail.tuwien.ac.at>
Diffstat (limited to 'desktop-widgets/downloadfromdivecomputer.cpp')
-rw-r--r--desktop-widgets/downloadfromdivecomputer.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/desktop-widgets/downloadfromdivecomputer.cpp b/desktop-widgets/downloadfromdivecomputer.cpp
index 50cbe223c..547c740c8 100644
--- a/desktop-widgets/downloadfromdivecomputer.cpp
+++ b/desktop-widgets/downloadfromdivecomputer.cpp
@@ -525,9 +525,9 @@ void DownloadFromDCWidget::on_ok_clicked()
// remember the last downloaded dive (on most dive computers this will be the chronologically
// first new dive) and select it again after processing all the dives
int uniqId = table->dives[table->nr - 1]->id;
- process_imported_dives(table, trips, preferDownloaded(), true, false);
+ add_imported_dives(table, trips, preferDownloaded(), true, false);
Command::clear();
// after process_imported_dives does any merging or resorting needed, we need
// to recreate the model for the dive list so we can select the newest dive
MainWindow::instance()->recreateDiveList();
int idx = get_idx_by_uniq_id(uniqId);
@@ -525,9 +525,9 @@ void DownloadFromDCWidget::on_ok_clicked()
Command::clear();
- // after process_imported_dives does any merging or resorting needed, we need
+ // after add_imported_dives does any merging or resorting needed, we need
// to recreate the model for the dive list so we can select the newest dive
MainWindow::instance()->recreateDiveList();